@@ -8,7 +8,7 @@ fn formatted_builder(test: bool) -> env_logger::Builder {
 }
 // 379d56a3 ends here
 
-// [[file:../gut.note::*pub][pub:1]]
+// [[file:../gut.note::3ba1b0d4][3ba1b0d4]]
 /// Setup logging for cmdline uses
 ///
 /// https://docs.rs/env_logger/*/env_logger/
@@ -24,10 +24,6 @@ pub fn setup_logger() {
         std::env::set_var("RUST_LOG", "debug");
     }
     formatted_builder(false).init();
-
-    if !log::log_enabled!(log::Level::Info) {
-        eprintln!("To see the full logging, try setting `RUST_LOG=info`.");
-    }
 }
 
 /// Setup logging for cargo test
@@ -36,7 +32,7 @@ pub fn setup_logger() {
 pub fn setup_logger_for_test() {
     // logging debug by default
     if std::env::var("RUST_LOG").is_err() {
-        std::env::set_var("RUST_LOG", "debug");
+        std::env::set_var("RUST_LOG", "info");
     }
 
     if let Err(e) = formatted_builder(true).try_init() {
@@ -53,4 +49,4 @@ pub fn setup_plain_logger() {
         .format(|buf, record| writeln!(buf, "{}", record.args()))
         .init();
 }
-// pub:1 ends here
+// 3ba1b0d4 ends here
